sequencetools.get_sequence_degree_of_rotational_symmetry
========================================================

.. autofunction:: abjad.tools.sequencetools.get_sequence_degree_of_rotational_symmetry.get_sequence_degree_of_rotational_symmetry
